@@ -14,7 +14,7 @@ from gi.repository import Gtk, Pango
 
 from gettext import gettext as _
 
-from lollypop.define import App, ArtSize, MARGIN, ViewType
+from lollypop.define import App, ArtSize, MARGIN, ViewType, Size
 from lollypop.define import SelectionListMask
 from lollypop.utils import popup_widget
 from lollypop.widgets_banner import BannerWidget
@@ -68,20 +68,6 @@ class PlaylistsBannerWidget(BannerWidget):
         self._overlay.add_overlay(grid)
         self._overlay.set_overlay_pass_through(grid, True)
 
-    def set_view_type(self, view_type):
-        """
-            Update view type
-            @param view_type as ViewType
-        """
-        BannerWidget.set_view_type(self, view_type)
-        title_context = self.__title_label.get_style_context()
-        for c in title_context.list_classes():
-            title_context.remove_class(c)
-        if view_type & ViewType.ADAPTIVE:
-            title_context.add_class("text-large")
-        else:
-            title_context.add_class("text-x-large")
-
     @property
     def height(self):
         """
@@ -90,6 +76,25 @@ class PlaylistsBannerWidget(BannerWidget):
         """
         return ArtSize.SMALL
 
+#######################
+# PROTECTED           #
+#######################
+    def _handle_width_allocate(self, allocation):
+        """
+            Update artwork
+            @param allocation as Gtk.Allocation
+        """
+        if BannerWidget._handle_width_allocate(self, allocation):
+            title_context = self.__title_label.get_style_context()
+            for c in title_context.list_classes():
+                title_context.remove_class(c)
+            if self.width <= Size.MEDIUM:
+                self.__title_label.get_style_context().add_class(
+                    "text-large")
+            else:
+                self.__title_label.get_style_context().add_class(
+                    "text-x-large")
+
 #######################
 # PRIVATE             #
 #######################
